DinuQ
=====

The DinuQ (Dinucleotide Quantification) Python3 package provides a range of metrics 
for quantifying nucleotide, dinucleotide and synonymous codon representation in genetic 
sequences. These include the recently developed corrected Synonymous Dinucleotide Usage 
(SDUc) and corrected Relative Synonymous Dinucleotide Usage (RSDUc).


*Current version: v.1.2.0*

<br>

## [📃 Installation Instructions & Documentation 📃](https://spyros-lytras.github.io/dinuq/)

<br>

## [📊 Visualise Results 📊](https://observablehq.com/@spyros-lytras/dinuq-viz)

<br>

## Citations: 
- *[Lytras, S.; Hughes, J. (2020) Synonymous Dinucleotide Usage: A Codon-Aware Metric for Quantifying Dinucleotide Representation in Viruses. Viruses, 12:462.](https://doi.org/10.3390/v12040462)*
- *[MacLean, O.<sup>#</sup>; Lytras, S.<sup>#</sup>; Weaver, S.; Singer, J.B.; Boni, M. F.; Lemey, P.; Kosakovsky Pond, S.L.; Robertson, D.L. (2021) Natural selection in the evolution of SARS-CoV-2 in bats created a generalist virus and highly capable human pathogen. PLoS Biol, 19(3):e3001115.](https://doi.org/10.1371/journal.pbio.3001115)*